DeviceConfig class
- Implemented types
Constructors
- DeviceConfig({String? id, String? model, String? manufacturer, String? os, String? osVersion, String? timezone, String? language})
- DeviceConfig.clear()
-
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
final
- language → String?
-
final
- manufacturer → String?
-
final
- model → String?
-
final
- os → String?
-
final
- osVersion → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timezone → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited